@@ -44,33 +44,33 @@ class Completions(SyncAPIResource):
 
     @with_sts_token
     def create(
-            self,
-            *,
-            messages: Iterable[ChatCompletionMessageParam],
-            model: str,
-            frequency_penalty: Optional[float] | None = None,
-            function_call: completion_create_params.FunctionCall | None = None,
-            logit_bias: Optional[Dict[str, int]] | None = None,
-            logprobs: Optional[bool] | None = None,
-            max_tokens: Optional[int] | None = None,
-            presence_penalty: Optional[float] | None = None,
-            stop: Union[Optional[str], List[str]] | None = None,
-            stream: Optional[Literal[False]] | Literal[True] = False,
-            stream_options: Optional[ChatCompletionStreamOptionsParam] | None = None,
-            temperature: Optional[float] | None = None,
-            tools: Iterable[ChatCompletionToolParam] | None = None,
-            top_logprobs: Optional[int] | None = None,
-            top_p: Optional[float] | None = None,
-            repetition_penalty: Optional[float] | None = None,
-            n: Optional[int] | None = None,
-            tool_choice: ChatCompletionToolChoiceOptionParam | None = None,
-            response_format: completion_create_params.ResponseFormat | None = None,
-            user: str | None = None,
-            metadata: Dict[str, object] | None = None,
-            extra_headers: Headers | None = None,
-            extra_query: Query | None = None,
-            extra_body: Body | None = None,
-            timeout: float | httpx.Timeout | None = None,
+        self,
+        *,
+        messages: Iterable[ChatCompletionMessageParam],
+        model: str,
+        frequency_penalty: Optional[float] | None = None,
+        function_call: completion_create_params.FunctionCall | None = None,
+        logit_bias: Optional[Dict[str, int]] | None = None,
+        logprobs: Optional[bool] | None = None,
+        max_tokens: Optional[int] | None = None,
+        presence_penalty: Optional[float] | None = None,
+        stop: Union[Optional[str], List[str]] | None = None,
+        stream: Optional[Literal[False]] | Literal[True] = False,
+        stream_options: Optional[ChatCompletionStreamOptionsParam] | None = None,
+        temperature: Optional[float] | None = None,
+        tools: Iterable[ChatCompletionToolParam] | None = None,
+        top_logprobs: Optional[int] | None = None,
+        top_p: Optional[float] | None = None,
+        repetition_penalty: Optional[float] | None = None,
+        n: Optional[int] | None = None,
+        tool_choice: ChatCompletionToolChoiceOptionParam | None = None,
+        response_format: completion_create_params.ResponseFormat | None = None,
+        user: str | None = None,
+        metadata: Dict[str, object] | None = None,
+        extra_headers: Headers | None = None,
+        extra_query: Query | None = None,
+        extra_body: Body | None = None,
+        timeout: float | httpx.Timeout | None = None,
     ) -> BotChatCompletion | Stream[BotChatCompletionChunk]:
         return self._post(
             "/bots/chat/completions",
@@ -95,7 +95,7 @@ class Completions(SyncAPIResource):
                 "n": n,
                 "tool_choice": tool_choice,
                 "response_format": response_format,
-                "metadata": metadata
+                "metadata": metadata,
             },
             options=make_request_options(
                 extra_headers=extra_headers,
@@ -120,33 +120,33 @@ class AsyncCompletions(AsyncAPIResource):
 
     @async_with_sts_token
     async def create(
-            self,
-            *,
-            messages: Iterable[ChatCompletionMessageParam],
-            model: str,
-            frequency_penalty: Optional[float] | None = None,
-            function_call: completion_create_params.FunctionCall | None = None,
-            logit_bias: Optional[Dict[str, int]] | None = None,
-            logprobs: Optional[bool] | None = None,
-            max_tokens: Optional[int] | None = None,
-            presence_penalty: Optional[float] | None = None,
-            stop: Union[Optional[str], List[str]] | None = None,
-            stream: Optional[Literal[False]] | Literal[True] = False,
-            stream_options: Optional[ChatCompletionStreamOptionsParam] | None = None,
-            temperature: Optional[float] | None = None,
-            tools: Iterable[ChatCompletionToolParam] | None = None,
-            top_logprobs: Optional[int] | None = None,
-            top_p: Optional[float] | None = None,
-            repetition_penalty: Optional[float] | None = None,
-            n: Optional[int] | None = None,
-            tool_choice: ChatCompletionToolChoiceOptionParam | None = None,
-            response_format: completion_create_params.ResponseFormat | None = None,
-            user: str | None = None,
-            metadata: Dict[str, object] | None = None,
-            extra_headers: Headers | None = None,
-            extra_query: Query | None = None,
-            extra_body: Body | None = None,
-            timeout: float | httpx.Timeout | None = None,
+        self,
+        *,
+        messages: Iterable[ChatCompletionMessageParam],
+        model: str,
+        frequency_penalty: Optional[float] | None = None,
+        function_call: completion_create_params.FunctionCall | None = None,
+        logit_bias: Optional[Dict[str, int]] | None = None,
+        logprobs: Optional[bool] | None = None,
+        max_tokens: Optional[int] | None = None,
+        presence_penalty: Optional[float] | None = None,
+        stop: Union[Optional[str], List[str]] | None = None,
+        stream: Optional[Literal[False]] | Literal[True] = False,
+        stream_options: Optional[ChatCompletionStreamOptionsParam] | None = None,
+        temperature: Optional[float] | None = None,
+        tools: Iterable[ChatCompletionToolParam] | None = None,
+        top_logprobs: Optional[int] | None = None,
+        top_p: Optional[float] | None = None,
+        repetition_penalty: Optional[float] | None = None,
+        n: Optional[int] | None = None,
+        tool_choice: ChatCompletionToolChoiceOptionParam | None = None,
+        response_format: completion_create_params.ResponseFormat | None = None,
+        user: str | None = None,
+        metadata: Dict[str, object] | None = None,
+        extra_headers: Headers | None = None,
+        extra_query: Query | None = None,
+        extra_body: Body | None = None,
+        timeout: float | httpx.Timeout | None = None,
     ) -> BotChatCompletion | AsyncStream[BotChatCompletionChunk]:
         return await self._post(
             "/bots/chat/completions",
@@ -171,7 +171,7 @@ class AsyncCompletions(AsyncAPIResource):
                 "n": n,
                 "tool_choice": tool_choice,
                 "response_format": response_format,
-                "metadata": metadata
+                "metadata": metadata,
             },
             options=make_request_options(
                 extra_headers=extra_headers,
